@@ -1,11 +1,8 @@
-#include <QContactManager>
 #include "contactsthreadworker.h"
 #include "k9call.h"
 
-using namespace QtMobility;
-
 ContactsThreadWorker::ContactsThreadWorker(k9call* k)
-    : QThread(0)
+    : QThread(0), m_Manager()
 {
 	// Setup connections
 	connect(this, SIGNAL(updateContacts(QList<QtMobility::QContact>)), 
@@ -24,13 +21,14 @@ void ContactsThreadWorker::run()
 void ContactsThreadWorker::syncContacts()
 {
 	qDebug() << "Sync Contacts ThreadId " << (int)QThread::currentThreadId();
-  QContactManager m;
+	qDebug() << "Got manager...";
 	QContactFetchHint hint;
 	QContactFetchHint::OptimizationHints optimizations = 0;
 	optimizations |= QContactFetchHint::NoBinaryBlobs;
 	optimizations |= QContactFetchHint::NoRelationships;
 	hint.setOptimizationHints(optimizations);
-	emit updateContacts(m.contacts(QList<QContactSortOrder>(), hint));
+	qDebug() << "Fetching...";
+	emit updateContacts(m_Manager.contacts(QList<QContactSortOrder>(), hint));
 }
 
 void ContactsThreadWorker::syncContactIds()
