@@ -11,6 +11,8 @@
 
 int main(int argc, char *argv[])
 {
+  // there seems to be a problem with the raster renderer :(
+  QApplication::setGraphicsSystem("opengl");
 	QApplication a(argc, argv);
 	
 	// General setup
